Documentation
¶
Overview ¶
Copyright © 2025 Gonzalo Alvarez
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.
Index ¶
- type Cmd
- type Executor
- type SystemCmd
- func (c *SystemCmd) CombinedOutput() ([]byte, error)
- func (c *SystemCmd) GetEnv(key string) string
- func (c *SystemCmd) Output() ([]byte, error)
- func (c *SystemCmd) Run() error
- func (c *SystemCmd) SetDir(dir string)
- func (c *SystemCmd) SetEnv(env []string)
- func (c *SystemCmd) SetExtraFiles(files []*os.File)
- func (c *SystemCmd) SetStderr(w io.Writer)
- func (c *SystemCmd) SetStdin(r io.Reader)
- func (c *SystemCmd) SetStdout(w io.Writer)
- func (c *SystemCmd) Start() error
- func (c *SystemCmd) Wait() error
- type SystemExecutor
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type SystemCmd ¶
type SystemCmd struct {
// contains filtered or unexported fields
}
func (*SystemCmd) CombinedOutput ¶
func (*SystemCmd) SetExtraFiles ¶
type SystemExecutor ¶
type SystemExecutor struct{}